import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import React from 'react';
import validator from 'validator';

export var Validator = function () {
  function Validator(message) {
    _classCallCheck(this, Validator);

    this.name = this.constructor.name;
    this.message = message;
  }

  Validator.prototype.convertValue = function convertValue(value) {
    return value && value.toString() || '';
  };

  Validator.prototype.isValid = function isValid(value) {
    return true;
  };

  Validator.prototype.isInvalid = function isInvalid(value) {
    return !this.isValid(value);
  };

  Validator.prototype.error = function error(name, value) {
    return this.message || 'Wrong value';
  };

  return Validator;
}();

export var EqualValidator = function (_Validator) {
  _inherits(EqualValidator, _Validator);

  function EqualValidator(value, message) {
    _classCallCheck(this, EqualValidator);

    var _this = _possibleConstructorReturn(this, _Validator.call(this, message));

    _this.value = value;
    return _this;
  }

  EqualValidator.prototype.isValid = function isValid(value) {
    return value === this.value;
  };

  EqualValidator.prototype.error = function error(name, value) {
    return this.message || 'This value is not equal.';
  };

  return EqualValidator;
}(Validator);

export var RegexValidator = function (_Validator2) {
  _inherits(RegexValidator, _Validator2);

  function RegexValidator(regex, message) {
    _classCallCheck(this, RegexValidator);

    var _this2 = _possibleConstructorReturn(this, _Validator2.call(this, message));

    _this2.regex = new RegExp(regex);
    return _this2;
  }

  RegexValidator.prototype.isValid = function isValid(value) {
    return this.regex.test(value);
  };

  RegexValidator.prototype.error = function error(name, value) {
    return this.message || 'This value is not valid.';
  };

  return RegexValidator;
}(Validator);

export var RequiredValidator = function (_Validator3) {
  _inherits(RequiredValidator, _Validator3);

  function RequiredValidator() {
    _classCallCheck(this, RequiredValidator);

    return _possibleConstructorReturn(this, _Validator3.apply(this, arguments));
  }

  RequiredValidator.prototype.isValid = function isValid(value) {
    return !validator.isEmpty(this.convertValue(value));
  };

  RequiredValidator.prototype.error = function error(name, value) {
    return this.message || 'This value is required.';
  };

  return RequiredValidator;
}(Validator);

export var EmailValidator = function (_Validator4) {
  _inherits(EmailValidator, _Validator4);

  function EmailValidator() {
    _classCallCheck(this, EmailValidator);

    return _possibleConstructorReturn(this, _Validator4.apply(this, arguments));
  }

  EmailValidator.prototype.isValid = function isValid(value) {
    return validator.isEmail(this.convertValue(value));
  };

  EmailValidator.prototype.error = function error(name, value) {
    return this.message || 'This value should be a valid email.';
  };

  return EmailValidator;
}(Validator);

export var WebSiteValidator = function (_Validator5) {
  _inherits(WebSiteValidator, _Validator5);

  function WebSiteValidator() {
    _classCallCheck(this, WebSiteValidator);

    return _possibleConstructorReturn(this, _Validator5.apply(this, arguments));
  }

  WebSiteValidator.prototype.isValid = function isValid(value) {
    return validator.isURL(this.convertValue(value));
  };

  WebSiteValidator.prototype.error = function error(name, value) {
    return this.message || 'This value should be a valid website.';
  };

  return WebSiteValidator;
}(Validator);

export var PhoneValidator = function (_Validator6) {
  _inherits(PhoneValidator, _Validator6);

  function PhoneValidator(locale, message) {
    _classCallCheck(this, PhoneValidator);

    var _this6 = _possibleConstructorReturn(this, _Validator6.call(this, message));

    _this6.locale = locale;
    return _this6;
  }

  PhoneValidator.prototype.isValid = function isValid(value) {
    return validator.isMobilePhone(this.convertValue(value), this.locale);
  };

  PhoneValidator.prototype.error = function error(name, value) {
    return this.message || 'This value should be a valid phone number.';
  };

  return PhoneValidator;
}(Validator);

export var CurrencyValidator = function (_Validator7) {
  _inherits(CurrencyValidator, _Validator7);

  function CurrencyValidator() {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : { allow_negatives: false };
    var message = arguments[1];

    _classCallCheck(this, CurrencyValidator);

    var _this7 = _possibleConstructorReturn(this, _Validator7.call(this, message));

    _this7.options = options;
    return _this7;
  }

  CurrencyValidator.prototype.isValid = function isValid(value) {
    return validator.isCurrency(this.convertValue(value), this.options);
  };

  CurrencyValidator.prototype.error = function error(name, value) {
    return this.message || 'This value is not currency amount.';
  };

  return CurrencyValidator;
}(Validator);

export var PasswordValidator = function (_RegexValidator) {
  _inherits(PasswordValidator, _RegexValidator);

  // https://www.thepolyglotdeveloper.com/2015/05/use-regex-to-test-password-strength-in-javascript/
  function PasswordValidator() {
    var strong = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;
    var message = arguments[1];

    _classCallCheck(this, PasswordValidator);

    var _this8 = _possibleConstructorReturn(this, _RegexValidator.call(this, strong ? PasswordValidator.strongRegex : PasswordValidator.mediumRegex, message));

    _this8.strong = strong;
    return _this8;
  }

  PasswordValidator.prototype.error = function error(name, value) {
    if (this.strong) {
      return 'The string must contain at least 1 lowercase alphabetical character, ' + 'at least 1 uppercase alphabetical character, ' + 'at least 1 numeric character and ' + 'at least one special character';
    }
    return 'The string must contain at least 1 lowercase or uppercase alphabetical character and ' + 'at least 1 numeric character';
  };

  return PasswordValidator;
}(RegexValidator);

PasswordValidator.strongRegex = '^(?=.*[a-z])(?=.*[A-Z])(?=.*[0-9])(?=.*[!@#\$%\^&\*])';
PasswordValidator.mediumRegex = '^((?=.*[a-z])(?=.*[A-Z]))|((?=.*[a-z])(?=.*[0-9]))|((?=.*[A-Z])(?=.*[0-9]))';
export var MinLengthValidator = function (_Validator8) {
  _inherits(MinLengthValidator, _Validator8);

  function MinLengthValidator(minLength, message) {
    _classCallCheck(this, MinLengthValidator);

    var _this9 = _possibleConstructorReturn(this, _Validator8.call(this, message));

    _this9.minLength = minLength;
    return _this9;
  }

  MinLengthValidator.prototype.isValid = function isValid(value) {
    return validator.isLength(this.convertValue(value), { min: this.minLength });
  };

  MinLengthValidator.prototype.error = function error(name, value) {
    return this.message || 'This value is too short. It should have ' + this.minLength + ' characters or more.';
  };

  return MinLengthValidator;
}(Validator);

export var MaxLengthValidator = function (_Validator9) {
  _inherits(MaxLengthValidator, _Validator9);

  function MaxLengthValidator(maxLength, message) {
    _classCallCheck(this, MaxLengthValidator);

    var _this10 = _possibleConstructorReturn(this, _Validator9.call(this, message));

    _this10.maxLength = maxLength;
    return _this10;
  }

  MaxLengthValidator.prototype.isValid = function isValid(value) {
    return validator.isLength(this.convertValue(value), { max: this.maxLength });
  };

  MaxLengthValidator.prototype.error = function error(name, value) {
    return this.message || 'This value is too long. It should have ' + this.maxLength + ' characters or less.';
  };

  return MaxLengthValidator;
}(Validator);

export var NumberValidator = function (_Validator10) {
  _inherits(NumberValidator, _Validator10);

  function NumberValidator() {
    _classCallCheck(this, NumberValidator);

    return _possibleConstructorReturn(this, _Validator10.apply(this, arguments));
  }

  NumberValidator.prototype.isValid = function isValid(value) {
    return validator.isInt(this.convertValue(value)) || validator.isFloat(this.convertValue(value));
  };

  NumberValidator.prototype.error = function error(name, value) {
    return this.message || 'This value is not a number.';
  };

  return NumberValidator;
}(Validator);

export var MinValueValidator = function (_NumberValidator) {
  _inherits(MinValueValidator, _NumberValidator);

  function MinValueValidator(minValue, message) {
    _classCallCheck(this, MinValueValidator);

    var _this12 = _possibleConstructorReturn(this, _NumberValidator.call(this, message));

    _this12.minValue = minValue;
    return _this12;
  }

  MinValueValidator.prototype.isValid = function isValid(value) {
    return _NumberValidator.prototype.isValid.call(this, value) && value >= this.minValue;
  };

  MinValueValidator.prototype.error = function error(name, value) {
    return this.message || 'This value is too small. It should be ' + this.minValue + ' or more.';
  };

  return MinValueValidator;
}(NumberValidator);

export var MaxValueValidator = function (_NumberValidator2) {
  _inherits(MaxValueValidator, _NumberValidator2);

  function MaxValueValidator(maxValue, message) {
    _classCallCheck(this, MaxValueValidator);

    var _this13 = _possibleConstructorReturn(this, _NumberValidator2.call(this, message));

    _this13.maxValue = maxValue;
    return _this13;
  }

  MaxValueValidator.prototype.isValid = function isValid(value) {
    return _NumberValidator2.prototype.isValid.call(this, value) && value <= this.maxValue;
  };

  MaxValueValidator.prototype.error = function error(name, value) {
    return this.message || 'This value is too big. It should be ' + this.maxValue + ' or less.';
  };

  return MaxValueValidator;
}(NumberValidator);