'use strict';

exports.__esModule = true;
exports.formConnector = exports.Form = undefined;

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _lodash = require('lodash');

var _utils = require('./utils');

var _formContext = require('./form-context');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Form = function (_React$Component) {
  (0, _inherits3.default)(Form, _React$Component);

  function Form(props, context) {
    (0, _classCallCheck3.default)(this, Form);

    var _this = (0, _possibleConstructorReturn3.default)(this, _React$Component.call(this, props, context));

    _this.onSubmit = function () {
      return _this.__onSubmit__REACT_HOT_LOADER__.apply(_this, arguments);
    };

    _this.formContext = new _formContext.FormContext();
    _this.formContext.setValidators(props.validators);
    _this.formContext.setValidatorsOptions(props.validatorsOptions);
    _this.formContext.setAsyncValidator(props.asyncValidator);
    _this.formContext.setAsyncValidatorOptions(props.asyncValidatorOptions);
    return _this;
  }

  Form.prototype.getChildContext = function getChildContext() {
    return { form: this.formContext };
  };

  Form.prototype.componentDidMount = function componentDidMount() {
    this.formContext.initialized = true;
    this.formContext.update();
  };

  Form.prototype.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    this.formContext.setValidators(nextProps.validators);
    this.formContext.setValidatorsOptions(nextProps.validatorsOptions);
    this.formContext.setAsyncValidator(nextProps.asyncValidator);
    this.formContext.setAsyncValidatorOptions(nextProps.asyncValidatorOptions);
    this.formContext.update();
  };

  Form.prototype.componentWillUnmount = function componentWillUnmount() {
    this.formContext.clear();
  };

  Form.prototype.__onSubmit__REACT_HOT_LOADER__ = function __onSubmit__REACT_HOT_LOADER__(e) {
    e.preventDefault();
    var isFormContextValid = this.formContext.isValid();
    if (isFormContextValid) {
      var _props$onSubmit = this.props.onSubmit,
          onSubmit = _props$onSubmit === undefined ? function () {} : _props$onSubmit;

      onSubmit(this.formContext.fields.getValues());
    } else {
      this.formContext.fields.updateFieldsAsUsed();
    }
  };

  Form.prototype.reset = function reset() {
    var value = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    this.formContext.reset(value);
  };

  Form.prototype.render = function render() {
    var children = this.props.children;

    return _react2.default.createElement(
      'form',
      (0, _extends3.default)({}, (0, _utils.getElementProps)(this.props), { onSubmit: this.onSubmit, noValidate: true }),
      children
    );
  };

  return Form;
}(_react2.default.Component);

Form.propTypes = {
  name: _propTypes2.default.any,
  children: _propTypes2.default.any,
  onSubmit: _propTypes2.default.any
};
Form.childContextTypes = {
  form: _propTypes2.default.instanceOf(_formContext.FormContext).isRequired
};

var formConnector = function formConnector(component) {
  return function (c) {
    var WrapperComponent = function (_React$Component2) {
      (0, _inherits3.default)(WrapperComponent, _React$Component2);

      function WrapperComponent() {
        (0, _classCallCheck3.default)(this, WrapperComponent);
        return (0, _possibleConstructorReturn3.default)(this, _React$Component2.apply(this, arguments));
      }

      WrapperComponent.prototype.componentDidMount = function componentDidMount() {
        var _this3 = this;

        this.fieldsSubscriberId = this.context.form.fields.subscribe(function () {
          _this3.forceUpdate();
        });
        this.validatorsSubscriberId = this.context.form.validators.subscribe(function () {
          _this3.forceUpdate();
        });
      };

      WrapperComponent.prototype.componentWillUnmount = function componentWillUnmount() {
        this.context.form.fields.removeSubscriber(this.fieldsSubscriberId);
        this.context.form.validators.removeSubscriber(this.validatorsSubscriberId);
        this.fieldsSubscriberId = null;
        this.validatorsSubscriberId = null;
      };

      WrapperComponent.prototype.render = function render() {
        var form = this.context.form;
        var props = {
          dirty: false,
          pristine: true,
          touched: false,
          isValid: form.isValid(),
          fields: form.fields.getFieldsOptions(),
          formErrors: form.validators.errors,
          fieldsErrors: form.fields.getErrors()
        };
        (0, _lodash.forEach)(form.fields.getFieldsOptions(), function (field) {
          if (field.dirty) {
            props.dirty = true;
            props.pristine = false;
          }
          if (field.touched) {
            props.touched = true;
          }
        });
        return _react2.default.createElement(c, (0, _extends3.default)({}, this.props, { form: props }));
      };

      return WrapperComponent;
    }(_react2.default.Component);

    WrapperComponent.contextTypes = {
      form: _propTypes2.default.instanceOf(_formContext.FormContext).isRequired
    };
    return WrapperComponent;
  }(component);
};

exports.Form = Form;
exports.formConnector = formConnector;
;

var _temp = function () {
  if (typeof __REACT_HOT_LOADER__ === 'undefined') {
    return;
  }

  __REACT_HOT_LOADER__.register(Form, 'Form', 'E:/Projects/React/git/vb-react-form/src/form.js');

  __REACT_HOT_LOADER__.register(formConnector, 'formConnector', 'E:/Projects/React/git/vb-react-form/src/form.js');
}();

;